==> vradi-entities-0.0.3-sources.jar: com/jurismarches/vradi/entities/XmlStreamBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class XmlStreamBean extends BusinessEntityBean implements XmlStream {

    private static final long serialVersionUID = -2016276767L;

    public XmlStreamBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String XmlStream$url;

     public String XmlStream$name;

     public Set<String> XmlStream$xmlFieldBinding;

 
    public void setUrl(String value) {
        Object oldValue = XmlStream$url; 
        this.XmlStream$url = value;
        propertyChange.firePropertyChange("url", oldValue, value);
    }

    public String getUrl() {
        return XmlStream$url;
    }


    public void setName(String value) {
        Object oldValue = XmlStream$name; 
        this.XmlStream$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return XmlStream$name;
    }

    public Set<String> getXmlFieldBinding() {
        return XmlStream$xmlFieldBinding;
    }

    public void addXmlFieldBinding(String element) {
        XmlStream$xmlFieldBinding.add(element);
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }
    
    public void removeXmlFieldBinding(String element) {
        XmlStream$xmlFieldBinding.remove(element);
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }
    
    public void clearXmlFieldBinding() {
        XmlStream$xmlFieldBinding.clear();
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }


} //XmlStreamBean

==> vradi-entities-0.0.4-sources.jar: com/jurismarches/vradi/entities/XmlStreamBean.java <==
package com.jurismarches.vradi.entities;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.util.Set;
import org.sharengo.wikitty.BusinessEntityBean;

public class XmlStreamBean extends BusinessEntityBean implements XmlStream {

    private static final long serialVersionUID = -672613865L;

    public XmlStreamBean() {
        super();
    }

     protected PropertyChangeSupport propertyChange = new PropertyChangeSupport(this);

    public void addPropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(listener);
	}

	public void removePropertyChangeListener(PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(listener);
	}

	public void addPropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.addPropertyChangeListener(propertyName, listener);
	}

	public void removePropertyChangeListener(String propertyName,PropertyChangeListener listener) {
		propertyChange.removePropertyChangeListener(propertyName, listener);
	}

    public String XmlStream$url;

     public String XmlStream$name;

     public String XmlStream$formTypeName;

     public Set<String> XmlStream$xmlFieldBinding;

 
    public void setUrl(String value) {
        Object oldValue = XmlStream$url; 
        this.XmlStream$url = value;
        propertyChange.firePropertyChange("url", oldValue, value);
    }

    public String getUrl() {
        return XmlStream$url;
    }


    public void setName(String value) {
        Object oldValue = XmlStream$name; 
        this.XmlStream$name = value;
        propertyChange.firePropertyChange("name", oldValue, value);
    }

    public String getName() {
        return XmlStream$name;
    }


    public void setFormTypeName(String value) {
        Object oldValue = XmlStream$formTypeName; 
        this.XmlStream$formTypeName = value;
        propertyChange.firePropertyChange("formTypeName", oldValue, value);
    }

    public String getFormTypeName() {
        return XmlStream$formTypeName;
    }

    public Set<String> getXmlFieldBinding() {
        return XmlStream$xmlFieldBinding;
    }

    public void addXmlFieldBinding(String element) {
        XmlStream$xmlFieldBinding.add(element);
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }
    
    public void removeXmlFieldBinding(String element) {
        XmlStream$xmlFieldBinding.remove(element);
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }
    
    public void clearXmlFieldBinding() {
        XmlStream$xmlFieldBinding.clear();
        propertyChange.firePropertyChange("xmlFieldBinding", null, XmlStream$xmlFieldBinding);
    }


} //XmlStreamBean
